.. Python musiXmatch documentation master file, created by
   sphinx-quickstart on Mon Mar 28 22:28:39 2011.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Package overview
================

.. automodule:: musixmatch.__init__

.. include:: ../README.rst

.. include:: ../CHANGES.rst

Package API
===========

.. toctree::
   :numbered:

   api
   ws
   base
   artist
   track
   album
   lyrics
   subtitle

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

